"use client";

import { useEffect, useState } from "react";

interface User {
  id: number;
  name: string;
  username: string;
  email: string;
  address: {
    street: string;
    suite: string;
    city: string;
    zipcode: string;
    geo: {
      lat: string;
      lng: string;
    };
  };
  phone: string;
  website: string;
  company: {
    name: string;
    catchPhrase: string;
    bs: string;
  };
}


interface MeUSer {
  id: number;
  name: string;
}


const InputWithList: React.FC = () => {
  const [text, setText] = useState<string>(""); 
  const [items, setItems] = useState<string[]>([]);
  const [data, setData] = useState<User[] | null>(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch("https://jsonplaceholder.typicode.com/users");
        const users: User[] = await response.json();
        setData(users);
      } catch (error) {
        console.error("Error fetching data:", error);
      }
    };

    fetchData();
  }, []);

  const handleAddItem = () => {
    if (text.trim() !== "") {
      setItems([...items, text]);
      setText(""); 
    }
  };

  return (
    <div className="p-6 max-w-md mx-auto bg-white rounded-xl shadow-md space-y-4">
      <h1 className="text-2xl font-bold text-gray-800">Text Input and List</h1>
      <div className="flex space-x-2">
        <input
          type="text"
          value={text}
          onChange={(e) => setText(e.target.value)}
          placeholder="Enter your text"
          className="flex-1 p-2 border rounded-md border-gray-300 focus:outline-none focus:ring-2 focus:ring-blue-400"
        />
        <button
          onClick={handleAddItem}
          className="px-4 py-2 bg-blue-500 text-white rounded-md hover:bg-blue-600 focus:outline-none"
        >
          Add
        </button>
      </div>
      <ul className="list-disc pl-6 space-y-1 text-gray-700">
        {items.map((item, index) => (
          <li key={index}>{item}</li>
        ))}
      </ul>
      {data && (
        <div className="text-gray-700">
          <h2 className="font-bold">Fetched Users:</h2>
          <ul className="list-disc pl-6 space-y-1">
            {data.map((user) => (
              <li key={user.id}>
                {user.id} {user.name} {user.phone}
              </li>
            ))}
          </ul>
        </div>
      )}
    </div>
  );
};

export default InputWithList;
